@@ -12,19 +12,20 @@ HTML::Auto::Templates - this module stores HTML::Auto templates
 
 =head1 VERSION
 
-Version 0.02
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my $templates = {
 
 'matrix' => <<'EOT'
 <style type="text/css">
 span.vertical {
-    -webkit-transform: rotate(-90deg);
-    -moz-transform: rotate(-90deg);
+    -webkit-transform: rotate(180deg);
+    -moz-transform: rotate(180deg);
+    transform: rotate(180deg);
     writing-mode: tb-rl;
     filter: flipv fliph;
     display: block;
@@ -33,7 +34,7 @@ span.vertical {
 }
 
 table.auto th {
-    padding-top: 70px;
+    padding-top: 24px;
     padding-bottom: 10px;
     padding-left: 5px;
     padding-right: 5px;
@@ -45,6 +46,7 @@ table.auto td {
     text-align: center;
     width: 30px;
     background-color: #eeeeee;
+    padding: 6px;
 }
 
 table.auto td.fst {
@@ -119,7 +121,7 @@ td.more_info:hover span {
 		[% FOREACH j IN i %]
 			<td
 				[% class = "" %]
-				[% IF i_c == j_c %]
+				[% IF diagonal AND i_c == j_c %]
 					[% class = "mid" %]
 				[% END %]
 				[% IF more.$i_c.$j_c %]
@@ -135,7 +137,7 @@ td.more_info:hover span {
 				[% FOREACH att IN attrs.$i_c.$j_c.keys %]
 					[% att %]="[% attrs.$i_c.$j_c.$att %]" 
 				[% END %]
-			>[% j %]
+			>[% IF myformat %][% j | format(myformat) %][% ELSE %][% j %][% END %]
 				[% IF more.$i_c.$j_c %]
 					<span>[% more.$i_c.$j_c %]</span> 
 				[% END %]
